@@ -7,7 +7,7 @@ import pandas as pd
 
 
 class AGRECL(object):
-    def __init__(self, data, distributor=None, compression='bz2'):
+    def __init__(self, data, distributor=None, compression='bz2', version=0):
         """
         :param data: list of dicts or absolute file_path
         :param distributor: str distributor REE code
@@ -17,7 +17,7 @@ class AGRECL(object):
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'AGRECL'
-        self.version = 0
+        self.version = version
         self.default_compression = compression
         self.distributor = distributor
 
