@@ -8,7 +8,7 @@ import pandas as pd
 
 
 class F1(object):
-    def __init__(self, data, distributor=None, compression='bz2'):
+    def __init__(self, data, distributor=None, compression='bz2', version=0):
         """
         :param data: list of dicts or absolute file_path
         :param distributor: str distributor REE code
@@ -20,7 +20,7 @@ class F1(object):
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'F1'
-        self.version = 0
+        self.version = version
         self.distributor = distributor
         self.default_compression = compression
 
