@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
+from mesures.dates import *
 from mesures.headers import F5D_HEADER as COLUMNS
 from mesures.f5 import F5, DTYPES
+import os
 import pandas as pd
 
 TYPES = DTYPES.copy()
@@ -8,7 +10,7 @@ TYPES.update({'factura': 'category'})
 
 
 class F5D(F5):
-    def __init__(self, data, distributor=None, comer=None, compression='bz2', columns=COLUMNS, dtypes=TYPES):
+    def __init__(self, data, distributor=None, comer=None, compression='bz2', columns=COLUMNS, dtypes=TYPES, version=0):
         """
         :param data: list of dicts or absolute file_path
         :param distributor: str distributor REE code
@@ -16,9 +18,26 @@ class F5D(F5):
         :param compression: 'bz2', 'gz'... OR False otherwise
         """
         super(F5D, self).__init__(data, distributor=distributor, comer=comer, compression=compression,
-                                  columns=columns, dtypes=dtypes)
+                                  columns=columns, dtypes=dtypes, version=version)
         self.prefix = 'F5D'
 
+    @property
+    def filename(self):
+        filename = "{prefix}_{distributor}_{comer}_{timestamp}.{version}".format(
+            prefix=self.prefix, distributor=self.distributor, comer=self.comer,
+            timestamp=self.generation_date.strftime(SIMPLE_DATE_MASK), version=self.version
+        )
+        if self.default_compression:
+            filename += ".{compression}".format(compression=self.default_compression)
+        return filename
+
+    @property
+    def zip_filename(self):
+        return "{prefix}_{distributor}_{comer}_{timestamp}.zip".format(
+            prefix=self.prefix, distributor=self.distributor, comer=self.comer,
+            timestamp=self.generation_date.strftime(SIMPLE_DATE_MASK)
+        )
+
     def cut_by_dates(self, di, df):
         """
         Cut File by dates, discard > and <
@@ -53,3 +72,20 @@ class F5D(F5):
             df[key] = df[key].astype('int32')
         df = df[self.columns]
         return df
+
+    def writer(self):
+        """
+        :return: file path of generated F5D File
+        """
+        file_path = os.path.join('/tmp', self.filename)
+        kwargs = {'sep': ';',
+                  'header': False,
+                  'columns': self.columns,
+                  'index': False,
+                  'line_terminator': ';\n'
+                  }
+        if self.default_compression:
+            kwargs.update({'compression': self.default_compression})
+
+        self.file.to_csv(file_path, **kwargs)
+        return file_path
